cmd

package
v1.0.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: May 8, 2026 License: Apache-2.0 Imports: 16 Imported by: 0

Documentation

Overview

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func Execute

func Execute()

Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.

func HandlePath

func HandlePath(path string, action func(string))

func PerformAudit

func PerformAudit(filePath string)

func PerformClean

func PerformClean(filePath string)

func PerformComment

func PerformComment(filePath, comment string)

func PerformConvert

func PerformConvert(filePath, format string)

func PerformGenerate

func PerformGenerate(name, kType string)

func PerformHunt

func PerformHunt(root string)

func PerformInspect

func PerformInspect(filePath string)

func PerformMatch

func PerformMatch(root string)

func PerformPublic

func PerformPublic(filePath string)

func PerformScore

func PerformScore(filePath string)

Types

type AuditResult

type AuditResult struct {
	FilePath        string   `json:"file_path"`
	Permissions     string   `json:"permissions"`
	IsPermSecure    bool     `json:"is_perm_secure"`
	Strength        string   `json:"strength"`
	IsStrong        bool     `json:"is_strong"`
	Recommendations []string `json:"recommendations,omitempty"`
	ErrorMessage    string   `json:"error_message,omitempty"`
}

type CleanResult

type CleanResult struct {
	FilePath     string `json:"file_path"`
	OutputPath   string `json:"output_path,omitempty"`
	Status       string `json:"status"`
	ErrorMessage string `json:"error_message,omitempty"`
}

type HuntResult

type HuntResult struct {
	FilePath    string  `json:"file_path"`
	Offset      int64   `json:"offset,omitempty"`
	Reason      string  `json:"reason"`
	Entropy     float64 `json:"entropy,omitempty"`
	ExtractedTo string  `json:"extracted_to,omitempty"`
}

type InspectResult

type InspectResult struct {
	FilePath       string `json:"file_path"`
	PEMType        string `json:"pem_type,omitempty"`
	KeyType        string `json:"key_type"`
	BitLength      int    `json:"bit_length,omitempty"`
	Fingerprint    string `json:"fingerprint,omitempty"`
	IsEncrypted    bool   `json:"is_encrypted"`
	Format         string `json:"format"`
	ForensicOrigin string `json:"forensic_origin,omitempty"`
	ErrorMessage   string `json:"error_message,omitempty"`
}

type PublicResult

type PublicResult struct {
	FilePath     string `json:"file_path"`
	PublicKey    string `json:"public_key,omitempty"`
	ErrorMessage string `json:"error_message,omitempty"`
}

type ScoreResult

type ScoreResult struct {
	FilePath     string  `json:"file_path"`
	Entropy      float64 `json:"entropy"`
	TrustScore   int     `json:"trust_score"`
	Assessment   string  `json:"assessment"`
	ErrorMessage string  `json:"error_message,omitempty"`
}

Jump to