Documentation
¶
Overview ¶
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Copyright © 2026 HNCLR by Poyraz Boreas Hancilar Licensed under the Apache License, Version 2.0
Index ¶
- func Execute()
- func HandlePath(path string, action func(string))
- func PerformAudit(filePath string)
- func PerformClean(filePath string)
- func PerformComment(filePath, comment string)
- func PerformConvert(filePath, format string)
- func PerformGenerate(name, kType string)
- func PerformHunt(root string)
- func PerformInspect(filePath string)
- func PerformMatch(root string)
- func PerformPublic(filePath string)
- func PerformScore(filePath string)
- type AuditResult
- type CleanResult
- type HuntResult
- type InspectResult
- type PublicResult
- type ScoreResult
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func Execute ¶
func Execute()
Execute adds all child commands to the root command and sets flags appropriately. This is called by main.main(). It only needs to happen once to the rootCmd.
func HandlePath ¶
func PerformAudit ¶
func PerformAudit(filePath string)
func PerformClean ¶
func PerformClean(filePath string)
func PerformComment ¶
func PerformComment(filePath, comment string)
func PerformConvert ¶
func PerformConvert(filePath, format string)
func PerformGenerate ¶
func PerformGenerate(name, kType string)
func PerformHunt ¶
func PerformHunt(root string)
func PerformInspect ¶
func PerformInspect(filePath string)
func PerformMatch ¶
func PerformMatch(root string)
func PerformPublic ¶
func PerformPublic(filePath string)
func PerformScore ¶
func PerformScore(filePath string)
Types ¶
type AuditResult ¶
type AuditResult struct {
FilePath string `json:"file_path"`
Permissions string `json:"permissions"`
IsPermSecure bool `json:"is_perm_secure"`
Strength string `json:"strength"`
IsStrong bool `json:"is_strong"`
Recommendations []string `json:"recommendations,omitempty"`
ErrorMessage string `json:"error_message,omitempty"`
}
type CleanResult ¶
type HuntResult ¶
type InspectResult ¶
type InspectResult struct {
FilePath string `json:"file_path"`
PEMType string `json:"pem_type,omitempty"`
KeyType string `json:"key_type"`
BitLength int `json:"bit_length,omitempty"`
Fingerprint string `json:"fingerprint,omitempty"`
IsEncrypted bool `json:"is_encrypted"`
Format string `json:"format"`
ForensicOrigin string `json:"forensic_origin,omitempty"`
ErrorMessage string `json:"error_message,omitempty"`
}